==> replacer-0.5.1%2B1.21.5-Fabric-sources.jar: eva/replacer/util/RelPos.java <==
package eva.replacer.util;

import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_243;

public class RelPos {
    private final int[] pos = new int[3];
    private static class_2338 basePos;
    private static class_243 baseVec;

    public static void setBase(class_2338 p) {
        basePos = p;
    }

    public static void setBase(class_243 v, class_2338 p) {
        basePos = p;
        baseVec = new class_243(
                v.method_10216() - p.method_10263(),
                v.method_10214() - p.method_10264(),
                v.method_10215() - p.method_10260()
        );
    }

    public RelPos(class_2338 pos) {
        this.pos[0] = pos.method_10263() - basePos.method_10263();
        this.pos[1] = pos.method_10264() - basePos.method_10264();
        this.pos[2] = pos.method_10260() - basePos.method_10260();
    }

    public RelPos(int... pos) {
        try {
            this.pos[0] = pos[0];
            this.pos[1] = pos[1];
            this.pos[2] = pos[2];
        } catch (ArrayIndexOutOfBoundsException e) {
            throw new RuntimeException(e);
        }
    }

    public class_243 vec() {
        class_243 v = pos().method_46558();
        return new class_243(
                v.method_10216() + baseVec.method_10216(),
                v.method_10214() + baseVec.method_10214(),
                v.method_10215() + baseVec.method_10215()
        );
    }

    public class_2338 pos() {
        return basePos
                .method_30513(class_2350.class_2351.field_11048, this.pos[0])
                .method_30513(class_2350.class_2351.field_11052, this.pos[1])
                .method_30513(class_2350.class_2351.field_11051, this.pos[2]);
    }

    public int[] vals() {
        return pos;
    }
    public boolean equals(RelPos tester) {
        return this.pos[0] == tester.pos[0] && this.pos[1] == tester.pos[1] && this.pos[2] == tester.pos[2];
    }
}

==> replacer-0.6.0%2B1.21.5-Fabric-sources.jar: eva/replacer/util/RelPos.java <==
package eva.replacer.util;

import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_243;

public class RelPos {
    private final int[] pos = new int[3];
    private static class_2338 basePos;
    private static class_243 baseVec;

    public static void setBase(class_2338 p) {
        basePos = p;
    }

    public static void setBase(class_243 v, class_2338 p) {
        basePos = p;
        baseVec = new class_243(
                v.method_10216() - p.method_10263(),
                v.method_10214() - p.method_10264(),
                v.method_10215() - p.method_10260()
        );
    }

    public RelPos(class_2338 pos) {
        this.pos[0] = pos.method_10263() - basePos.method_10263();
        this.pos[1] = pos.method_10264() - basePos.method_10264();
        this.pos[2] = pos.method_10260() - basePos.method_10260();
    }

    public RelPos(int... pos) {
        if (pos.length != 3) throw new IllegalArgumentException();
        this.pos[0] = pos[0];
        this.pos[1] = pos[1];
        this.pos[2] = pos[2];
    }

    public class_243 vec() {
        class_243 v = pos().method_46558();
        return new class_243(
                v.method_10216() + baseVec.method_10216(),
                v.method_10214() + baseVec.method_10214(),
                v.method_10215() + baseVec.method_10215()
        );
    }

    public class_2338 pos() {
        return basePos
                .method_30513(class_2350.class_2351.field_11048, this.pos[0])
                .method_30513(class_2350.class_2351.field_11052, this.pos[1])
                .method_30513(class_2350.class_2351.field_11051, this.pos[2]);
    }

    public int[] vals() {
        return pos;
    }
    public boolean equals(RelPos tester) {
        return this.pos[0] == tester.pos[0] && this.pos[1] == tester.pos[1] && this.pos[2] == tester.pos[2];
    }
}
